@@ -4,25 +4,21 @@ OC.L10N.register(
     "Bookmarks" : "Favoritter",
     "No file provided for import" : "Ingen fil til import",
     "Unsupported file type for import" : "Denne filtype er ikke understøttet til import",
-    "Recent Bookmarks" : "Seneste Bokmærker",
     "A Bookmark manager for Nextcloud" : "En app til at administrere bogmærker i Nextcloud",
     "Select bookmark" : "Vælg bogmærke",
     "Details" : "Detaljer",
     "Rename" : "Omdøb",
     "Move" : "Flyt",
     "Delete" : "Slet",
-    "Select one or more tags" : "Vælg et eller flere tags",
-    "New" : "Ny",
-    "New folder" : "Ny mappe",
-    "Grid view" : "Grid visning",
-    "List view" : "Vis som liste",
     "Move selection" : "Flyt valgte",
     "Delete selection" : "Slet valgte",
     "Select all" : "Vælg alle",
     "_Selected %n bookmark_::_Selected %n bookmarks_" : ["Valgt %n bogmærke","Valgt %n bogmærker"],
+    "Select one or more tags" : "Vælg et eller flere tags",
+    "New" : "Ny",
+    "New folder" : "Ny mappe",
     "Enter a link" : "Indtast et link",
     "Enter folder title" : "Angiv folder navn",
-    "Root folder" : "Rodmappe",
     "Submit" : "Tilføj",
     "Cancel" : "Annullér",
     "_Moving %n folder_::_Moving %n folders_" : ["Flytter %n mappe","Flytter %n mapper"],
@@ -30,14 +26,8 @@ OC.L10N.register(
     "All bookmarks" : "Alle bogmærker",
     "Recent" : "Seneste",
     "Untagged" : "Fravalgt",
-    "Add a bookmark" : "Tilføj et bogmærke",
     "Import" : "Importér",
     "Export" : "Eksportér",
-    "Sorting" : "Sortering",
-    "Recently added" : "Tilføjet for nylig",
-    "Alphabetically" : "Alfabetisk",
-    "Most visited" : "Mest besøgte",
-    "Last modified" : "Sidst ændret",
     "Client apps" : "Klient apps",
     "Bookmarklet" : "Bookmarklet",
     "Add to {instanceName}" : "Tilføj til {instanceName}",
@@ -46,26 +36,23 @@ OC.L10N.register(
     "Do you really want to delete all your bookmarks?" : "Ønsker du virkelig at slette alle dine bogmærker?",
     "Title" : "Titel",
     "Link" : "Link",
-    "Creation date" : "Oprettelsesdato",
     "Tags" : "Mærker",
-    "Attachments" : "Vedhæftede filer",
     "Notes" : "Noter",
-    "{time} ago" : "{time} siden",
     "Owner" : "Ejer",
     "Sharing" : "Deling",
     "Share link" : "Share link",
     "Copy link" : "Kopiér link",
     "Allow editing" : "Tillad redigering",
     "Link copied" : "Link kopieret",
-    "Select" : "Vælg",
+    "Privacy" : "Privatliv",
+    "Performance" : "Ydelse",
     "Previews" : "Forhåndsvisning",
     "Screeenly" : "Screeenly",
     "Screeenly API URL" : "Screeenly API URL",
     "Screeenly API key" : "Screeenly API nøgle",
-    "Privacy" : "Privatliv",
-    "Performance" : "Ydelse",
     "Failed to load settings" : "Fejl ved indlæsning af indstillinger",
     "Failed to save settings" : "Kunne ikke gemme indstillinger",
+    "Add a bookmark" : "Tilføj et bogmærke",
     "This URL is already bookmarked! Overwrite?" : "Denne URL har allerede et bogmærke. Overskriv?",
     "Enter bookmark title" : "Angiv titel på bogmærke",
     "Folder" : "Mappe",
