@@ -5,25 +5,19 @@ OC.L10N.register(
     "Rename" : "Renombrar",
     "Move" : "Mover",
     "Delete" : "Eliminar",
+    "Select all" : "Seleccionar todo",
     "New" : "Nuevo",
     "New folder" : "Carpeta nueva",
-    "Grid view" : "Vista de cuadrícula",
-    "List view" : "Vista de lista",
-    "Select all" : "Seleccionar todo",
     "Submit" : "Enviar",
     "Cancel" : "Cancelar",
     "Recent" : "Reciente",
     "Import" : "Importar",
     "Export" : "Exportar",
-    "Recently added" : "Agregado recientemente",
-    "Alphabetically" : "Alfabéticamente",
-    "Last modified" : "Última modificación",
     "Bookmarklet" : "Marcador a código",
     "Clear data" : "Borrar datos",
     "Title" : "Título",
     "Link" : "Link",
     "Tags" : "Etiquetas",
-    "Attachments" : "Adjuntos",
     "Notes" : "Notas",
     "Owner" : "Dueño",
     "Sharing" : "Compartiendo",
@@ -31,7 +25,6 @@ OC.L10N.register(
     "Copy link" : "Copiar enlace",
     "Allow editing" : "Permitir edición",
     "Link copied" : "Link copiado",
-    "Select" : "Seleccionar",
     "Privacy" : "Privacidad",
     "Folder" : "Carpeta",
     "Save" : "Guardar"
