@@ -9,21 +9,14 @@ OC.L10N.register(
     "Rename" : "Pārsaukt",
     "Move" : "Pārvietot",
     "Delete" : "Dzēst",
+    "Select all" : "Atzīmēt visu",
     "New" : "Jauns",
     "New folder" : "Jauna mape",
-    "Grid view" : "Režģa izkārtojums",
-    "List view" : "Saraksta izkārtojums",
-    "Select all" : "Atzīmēt visu",
     "Submit" : "Iesniegt",
     "Cancel" : "Atcelt",
     "Recent" : "Nesenās",
-    "Add a bookmark" : "Pievienot grāmatzīmi",
     "Import" : "Importēt",
     "Export" : "Eksportēt",
-    "Recently added" : "Nesen pievienoja",
-    "Alphabetically" : "Alfabētiskā secībā",
-    "Most visited" : "Visapmeklētākie",
-    "Last modified" : "Pēdējoreiz modificēts",
     "Bookmarklet" : "Grāmatzīme",
     "Clear data" : "Notīrīt datus",
     "Delete all bookmarks" : "Dzēst visas grāmatzīmes",
@@ -31,7 +24,6 @@ OC.L10N.register(
     "Title" : "Amats",
     "Link" : "Saite",
     "Tags" : "Birkas",
-    "Attachments" : "Pielikumi",
     "Notes" : "Piezīmes",
     "Owner" : "Īpašnieks",
     "Sharing" : "Koplietošana",
@@ -39,11 +31,11 @@ OC.L10N.register(
     "Copy link" : "Kopēt saiti",
     "Allow editing" : "Atļaut rediģēšanu",
     "Link copied" : "Saite nokopēta",
-    "Select" : "Atzīmēt",
+    "Privacy" : "Privātums",
     "Previews" : "Priekšskatījumi",
     "Screeenly API URL" : "Screeenly API saite",
     "Screeenly API key" : "Screeenly API atslēga",
-    "Privacy" : "Privātums",
+    "Add a bookmark" : "Pievienot grāmatzīmi",
     "This URL is already bookmarked! Overwrite?" : "Šī saite jau ir grāmatzīmēs! Vai pārrakstīt?",
     "Folder" : "Mape",
     "Save" : "Saglabāt",
