@@ -5,20 +5,15 @@ OC.L10N.register(
     "Rename" : "Rename",
     "Move" : "Move",
     "Delete" : "Delete",
+    "Select all" : "Označi sve",
     "New" : "Nov",
     "New folder" : "Nova fascikla",
-    "Grid view" : "Prikaz mreže",
-    "List view" : "Prikaz liste",
-    "Select all" : "Označi sve",
-    "Root folder" : "Korena fascikla",
     "Cancel" : "Otkaži",
     "Import" : "Uvezi",
-    "Recently added" : "Nedavno dodato",
     "Clear data" : "Očisti podatke",
     "Title" : "Naslov",
     "Link" : "Prečica",
     "Tags" : "Oznake",
-    "Attachments" : "Prilozi",
     "Notes" : "Notes",
     "Owner" : "Vlasnik",
     "Sharing" : "Deljenje",
@@ -26,7 +21,6 @@ OC.L10N.register(
     "Copy link" : "Kopiraj vezu",
     "Allow editing" : "Dozvoli uređivanje",
     "Link copied" : "Veza iskopirana",
-    "Select" : "Select",
     "Privacy" : "Privatnost",
     "Folder" : "Folder",
     "Save" : "Save"
